@@ -14,15 +14,15 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ContentHandler.h,v 1.31 2006/09/13 11:34:14 chpe Exp $
+ *  $Id: ContentHandler.h 7858 2008-01-13 20:42:01Z cosimoc $
  */
 
 #ifndef CONTENT_HANDLER_H
 #define CONTENT_HANDLER_H
 
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
+#include <gio/gio.h>
 
 #include <nsCOMPtr.h>
 #include <nsIFile.h>
@@ -70,7 +70,7 @@ class GContentHandler : public nsIHelperAppLauncherDialog
 	nsCOMPtr<nsIHelperAppLauncher> mLauncher;
 	nsCOMPtr<nsISupports> mContext;
 
-	GnomeVFSMimeApplication *mHelperApp;
+	GAppInfo *mHelperApp;
 	EphyMimePermission mPermission;
 
 	nsCString mUrl;
