@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyPromptService.cpp 6588 2006-09-13 11:34:25Z chpe $
+ *  $Id: EphyPromptService.cpp 7426 2007-09-13 13:18:57Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -514,7 +514,7 @@ static void
 DeletePrompter (gpointer aPromptPtr,
 	        GObject *aZombie)
 {
-	Prompter *prompt = NS_STATIC_CAST (Prompter*, aPromptPtr);
+	Prompter *prompt = static_cast<Prompter*>(aPromptPtr);
 
 	delete prompt;
 }
@@ -531,7 +531,7 @@ Prompter::Show ()
 			  G_CALLBACK (gtk_widget_destroy), NULL);
 	g_object_weak_ref (G_OBJECT (mDialog),
 			   (GWeakNotify) DeletePrompter,
-			   NS_STATIC_CAST (gpointer, this));
+			   static_cast<gpointer>(this));
 
 	gtk_widget_show (GTK_WIDGET (mDialog));
 }
