@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: GeckoPrintService.cpp 7295 2007-08-22 19:54:35Z chpe $
+ *  $Id: GeckoPrintService.cpp 7804 2007-12-23 22:02:02Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -650,7 +650,8 @@ GeckoPrintService::TranslateSettings (GtkPrintSettings *aGtkSettings,
   gtk_print_settings_set_page_ranges (aGtkSettings, NULL, 0);
   gtk_print_settings_set_page_set (aGtkSettings, GTK_PAGE_SET_ALL);
 
-  switch (gtk_print_settings_get_orientation (aGtkSettings)) {
+  /* We must use the page setup here instead of the print settings, see gtk bug #485685 */
+  switch (gtk_page_setup_get_orientation (aPageSetup)) {
     case GTK_PAGE_ORIENTATION_PORTRAIT:
     case GTK_PAGE_ORIENTATION_REVERSE_PORTRAIT: /* not supported */
       aSettings->SetOrientation (nsIPrintSettings::kPortraitOrientation);
@@ -664,7 +665,10 @@ GeckoPrintService::TranslateSettings (GtkPrintSettings *aGtkSettings,
   aSettings->SetPrintInColor (gtk_print_settings_get_use_color (aGtkSettings));
 
   aSettings->SetPaperSizeUnit(nsIPrintSettings::kPaperSizeMillimeters);
+
+#ifndef HAVE_GECKO_1_9
   aSettings->SetPaperSize (nsIPrintSettings::kPaperSizeDefined);
+#endif
 
   GtkPaperSize *paperSize = gtk_page_setup_get_paper_size (aPageSetup);
   if (!paperSize) {
@@ -749,7 +753,7 @@ GeckoPrintService::TranslateSettings (GtkPrintSettings *aGtkSettings,
    */
   /* gtk_print_settings_set_collate (aGtkSettings, FALSE); not yet */
   /* FIXME: Unset the orientation for the print job? */
-  /* gtk_print_settings_set_orientation (aGtkSettings, GTK_PAGE_ORIENTATION_PORTRAIT); */
+  /* gtk_page_setup_set_orientation (aPageSetup, GTK_PAGE_ORIENTATION_PORTRAIT); */
   /* FIXME: unset output format -> "ps" ? */
 
   return NS_OK;
