@@ -16,7 +16,7 @@
  *
  * The Initial Developer of the Original Code is
  * Netscape Communications Corporation.
- * Portions created by the Initial Developer are Copyright (C) 2002
+ * Portions created by the Initial Developer are Copyright © 2002
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -36,14 +36,12 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.h,v 1.25 2006/05/10 18:07:00 chpe Exp $
+ * $Id: MozDownload.h 7858 2008-01-13 20:42:01Z cosimoc $
  */
 
 #ifndef MozDownload_h__
 #define MozDownload_h__
 
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
-
 #include <nsCOMPtr.h>
 #include <nsIInterfaceRequestor.h>
 #include <nsITransfer.h>
@@ -138,6 +136,7 @@ protected:
 	PRInt64                 mTotalProgress;
 	PRInt64                 mCurrentProgress;
 	PRInt64			mMaxSize;
+	PRBool			mAddToRecent;
 
 	nsresult                mStatus;
 
