@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-location-entry.h 7020 2007-05-01 17:13:10Z xan $
+ *  $Id: ephy-location-entry.h 7828 2007-12-26 19:00:00Z diegoe $
  */
 
 #ifndef EPHY_LOCATION_ENTRY_H
@@ -28,6 +28,7 @@
 #include <gtk/gtkwidget.h>
 #include <gtk/gtktoolitem.h>
 #include <gtk/gtktreemodel.h>
+#include <gtk/gtkentrycompletion.h>
 
 G_BEGIN_DECLS
 
@@ -80,6 +81,10 @@ void		ephy_location_entry_set_location	(EphyLocationEntry *le,
 							 const char *address,
 							 const char *typed_address);
 
+void		ephy_location_entry_set_completion_func (EphyLocationEntry *le, 
+							 GtkEntryCompletionMatchFunc completion_func,
+							 gpointer user_data);
+					
 const char     *ephy_location_entry_get_location	(EphyLocationEntry *le);
 
 gboolean	ephy_location_entry_reset		(EphyLocationEntry *entry);
