@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-related-action.c,v 1.6 2006/09/13 11:34:25 chpe Exp $
+ *  $Id: ephy-related-action.c 7592 2007-10-28 13:53:29Z chpe $
  */
 
 #include "config.h"
@@ -54,10 +54,10 @@ node_destroyed (EphyNode *node,
 	ephy_topic_action_set_topic (action, favorites);
 }
 
-static EphyTab *
+static EphyEmbed *
 open_link (EphyLink *link,
 	   const char *address,
-	   EphyTab *tab,
+	   EphyEmbed *embed,
 	   EphyLinkFlags flags)
 {
 	EphyBookmarks *eb;
