@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  *  Copyright © 2000, 2001, 2002, 2003, 2004 Marco Pesenti Gritti
  *  Copyright © 2003, 2004, 2005 Christian Persch
@@ -16,11 +17,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-lockdown.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: ephy-lockdown.c 7695 2007-11-16 15:03:10Z xan $
  */
 
 #include "config.h"
 
+#include "ephy-embed-container.h"
 #include "ephy-lockdown.h"
 #include "ephy-extension.h"
 #include "ephy-action-helper.h"
@@ -88,7 +90,6 @@ update_location_editable (EphyWindow *window,
 			  GtkAction *action,
 			  gboolean editable)
 {
-	EphyTab *tab;
 	EphyEmbed *embed;
 	GtkWidget *toolbar;
 	char *address;
@@ -99,17 +100,14 @@ update_location_editable (EphyWindow *window,
 	if (editable == FALSE)
 	{
 		toolbar = ephy_window_get_toolbar (window);
-		tab = ephy_window_get_active_tab (window);
+		embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 		/* embed is NULL on startup */
-		if (tab != NULL)
+		if (embed != NULL)
 		{
-			embed = ephy_tab_get_embed (tab);
-			g_return_if_fail (embed != NULL);
-
 			address = ephy_embed_get_location (embed, TRUE);
 			ephy_toolbar_set_location (EPHY_TOOLBAR (toolbar), address, NULL);
-			ephy_tab_set_typed_address (tab, NULL,
-						    EPHY_TAB_ADDRESS_EXPIRE_CURRENT);
+			ephy_embed_set_typed_address (embed, NULL,
+                                                      EPHY_EMBED_ADDRESS_EXPIRE_CURRENT);
 			g_free (address);
 		}
 	}
@@ -123,7 +121,8 @@ update_window (EphyWindow *window,
 	       EphyLockdown *lockdown)
 {
 	GtkUIManager *manager;
-	GtkActionGroup *action_group, *popups_action_group, *toolbar_action_group;
+	GtkActionGroup *action_group, *popups_action_group;
+	GtkActionGroup *toolbar_action_group, *special_toolbar_action_group;
 	GtkAction *action;
 	gboolean disabled, fullscreen, print_setup_disabled, writable;
 
@@ -132,8 +131,12 @@ update_window (EphyWindow *window,
 	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
 	action_group = find_action_group (manager, "WindowActions");
 	popups_action_group = find_action_group (manager, "PopupsActions");
-	toolbar_action_group = find_action_group (manager, "SpecialToolbarActions");
-	g_return_if_fail (action_group != NULL && popups_action_group != NULL && toolbar_action_group != NULL);
+	toolbar_action_group = find_action_group (manager, "ToolbarActions");
+	special_toolbar_action_group = find_action_group (manager, "SpecialToolbarActions");
+	g_return_if_fail (action_group != NULL
+			  && popups_action_group != NULL
+			  && toolbar_action_group != NULL
+			  && special_toolbar_action_group != NULL);
 
 	disabled = eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINTING);
 	print_setup_disabled = eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINT_SETUP) ||
@@ -156,26 +159,26 @@ update_window (EphyWindow *window,
 	disabled = eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_ARBITRARY_URL);
 	action = gtk_action_group_get_action (action_group, "GoLocation");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
-	action = gtk_action_group_get_action (toolbar_action_group, "Location");
+	action = gtk_action_group_get_action (special_toolbar_action_group, "Location");
 	update_location_editable (window, action, !disabled);
-	action = gtk_action_group_get_action (toolbar_action_group, "NavigationUp");
+	action = gtk_action_group_get_action (special_toolbar_action_group, "NavigationUp");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 
 	disabled = eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_HISTORY);
 	action = gtk_action_group_get_action (action_group, "GoHistory");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
-	action = gtk_action_group_get_action (toolbar_action_group, "NavigationBack");
+	action = gtk_action_group_get_action (special_toolbar_action_group, "NavigationBack");
+	gtk_action_set_visible (action, !disabled);
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
-	action = gtk_action_group_get_action (toolbar_action_group, "NavigationForward");
+	action = gtk_action_group_get_action (special_toolbar_action_group, "NavigationForward");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
+	gtk_action_set_visible (action, !disabled);
 
 	disabled = eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING);
 	action = gtk_action_group_get_action (action_group, "GoBookmarks");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 	action = gtk_action_group_get_action (action_group, "FileBookmarkPage");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
-	action = gtk_action_group_get_action (popups_action_group, "ContextBookmarkPage");
-	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 	action = gtk_action_group_get_action (popups_action_group, "BookmarkLink");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 
@@ -197,9 +200,15 @@ update_window (EphyWindow *window,
 	disabled = eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_TOOLBAR_EDITING);
 	action = gtk_action_group_get_action (action_group, "ViewToolbarEditor");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
+	action = gtk_action_group_get_action (toolbar_action_group, "MoveToolItem");
+	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
+	action = gtk_action_group_get_action (toolbar_action_group, "RemoveToolItem");
+	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
+	action = gtk_action_group_get_action (toolbar_action_group, "RemoveToolbar");
+	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 
 	fullscreen = eel_gconf_get_boolean (CONF_LOCKDOWN_FULLSCREEN);
-	action = gtk_action_group_get_action (toolbar_action_group, "FileNewWindow");
+	action = gtk_action_group_get_action (special_toolbar_action_group, "FileNewWindow");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, fullscreen);
 	action = gtk_action_group_get_action (action_group, "ViewFullscreen");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, fullscreen);
