@@ -15,19 +15,19 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-notebook.h 6588 2006-09-13 11:34:25Z chpe $
+ *  $Id: ephy-notebook.h 7587 2007-10-28 13:25:28Z chpe $
  */
 
 #ifndef EPHY_NOTEBOOK_H
 #define EPHY_NOTEBOOK_H
 
-#include "ephy-tab.h"
-
 #include <glib.h>
 #include <gtk/gtknotebook.h>
 
+#include "ephy-embed.h"
+
 G_BEGIN_DECLS
 
 #define EPHY_TYPE_NOTEBOOK		(ephy_notebook_get_type ())
@@ -55,13 +55,13 @@ struct _EphyNotebookClass
 
 	/* Signals */
 	void	 (* tab_close_req)  (EphyNotebook *notebook,
-				     EphyTab *tab);
+				     EphyEmbed *embed);
 };
 
 GType		ephy_notebook_get_type		(void);
 
 int		ephy_notebook_add_tab		(EphyNotebook *nb,
-						 EphyTab *tab,
+						 EphyEmbed *embed,
 						 int position,
 						 gboolean jump_to);
 	
